@@ -37,7 +37,7 @@ def _check(resp: requests.models.Response) -> None:
                   " has therefore not been pwned")
         elif resp.status_code == 429:
             print("Too many requests: The rate limit has been exceeded\n")
-            print(resp.text)  # lgtm [py/clear-text-logging-sensitive-data]
+            print(resp.text)  # lgtm[py/clear-text-logging-sensitive-data]
     except requests.RequestException:
         print("ERROR: Could not connect to server")
 
@@ -343,7 +343,7 @@ class Pwned:
             data = resp.json()
             if not isinstance(data, list):
                 return [data]
-            return data
+            # return data  # Pretty sure will never hit
         return resp.status_code
 
     def data_classes(self) -> Union[int, List[str]]:
@@ -445,12 +445,14 @@ class Pwned:
               >>> data = foo.search_password("BadPassword")
         """
         url = "https://api.pwnedpasswords.com/range/"
-        hash_object = hashlib.sha1(
-            bytes(password,
-                  encoding="utf-8"))  # lgtm [py/weak-sensitive-data-hashing]
+        hash_object = hashlib.sha1(  # lgtm[py/weak-sensitive-data-hashing]
+            bytes(  # lgtm[py/weak-sensitive-data-hashing]
+                password,  # lgtm[py/weak-sensitive-data-hashing]
+                encoding="utf-8"))  # lgtm[py/weak-sensitive-data-hashing]
         hexdig = hash_object.hexdigest()
         hexdig = hexdig.upper()
         hsh = hexdig[:5]
+        pnum = '0'
         resp = requests.get(url + hsh, headers=self.header)
         _check(resp)
         if resp.status_code == 200:
